JBoss Rich Faces SVN: r2517 - trunk/framework/impl/src/main/java/org/ajax4jsf/component.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2007-08-27 14:36:15 -0400 (Mon, 27 Aug 2007)
New Revision: 2517
Modified:
trunk/framework/impl/src/main/java/org/ajax4jsf/component/UIDataAdaptor.java
Log:
http://jira.jboss.com/jira/browse/RF-565 fixed
Modified: trunk/framework/impl/src/main/java/org/ajax4jsf/component/UIDataAdaptor.java
===================================================================
--- trunk/framework/impl/src/main/java/org/ajax4jsf/component/UIDataAdaptor.java 2007-08-27 18:33:45 UTC (rev 2516)
+++ trunk/framework/impl/src/main/java/org/ajax4jsf/component/UIDataAdaptor.java 2007-08-27 18:36:15 UTC (rev 2517)
@@ -183,6 +183,11 @@
*/
private Set _ajaxKeys = null;
+ /**
+ * Internal set of row keys, encoded on ajax response rendering and cleared after response complete
+ */
+ private Set _ajaxRequestKeys = null;
+
private Object _ajaxRowKey = null;
private Map _ajaxRowKeysMap = new HashMap();
@@ -342,7 +347,27 @@
}
return keys;
}
+
+ public Set getAllAjaxKeys() {
+ Set ajaxKeys = getAjaxKeys();
+
+ Set allAjaxKeys = null;
+ if (ajaxKeys != null) {
+ allAjaxKeys = new HashSet();
+ allAjaxKeys.addAll(ajaxKeys);
+ }
+
+ if (_ajaxRequestKeys != null) {
+ if (allAjaxKeys == null) {
+ allAjaxKeys = new HashSet();
+ }
+
+ allAjaxKeys.addAll(_ajaxRequestKeys);
+ }
+ return allAjaxKeys;
+ }
+
/*
* (non-Javadoc)
*
@@ -388,7 +413,7 @@
}
};
- Set ajaxKeys = getAjaxKeys();
+ Set ajaxKeys = getAllAjaxKeys();
if (null != ajaxKeys) {
if(_log.isDebugEnabled()){
_log.debug("Component "+getClientId(context)+" Encode children components for a keys "+ajaxKeys);
@@ -1359,4 +1384,45 @@
this._baseClientId = null;
}
+ /**
+ * Adds argument key to AJAX internal request keys set
+ * @param key key to add
+ */
+ public void addRequestKey(Object key) {
+ if (_ajaxRequestKeys == null) {
+ _ajaxRequestKeys = new HashSet();
+ }
+
+ _ajaxRequestKeys.add(key);
+ }
+
+ /**
+ * Removes argument key from AJAX internal request keys set
+ * @param key key to remove
+ */
+ public void removeRequestKey(Object key) {
+ if (_ajaxRequestKeys != null && key != null) {
+ _ajaxRequestKeys.remove(key);
+ }
+ }
+
+ /**
+ * Checks whether AJAX internal request keys set contains argument key
+ * @param key key to check
+ * @return <code>true</code> if set contains key, <code>false</code> - otherwise
+ */
+ public boolean containsRequestKey(Object key) {
+ if (_ajaxRequestKeys != null && key != null) {
+ return _ajaxRequestKeys.contains(key);
+ }
+
+ return false;
+ }
+
+ /**
+ * Clears AJAX internal request keys set
+ */
+ public void clearRequestKeysSet() {
+ _ajaxRequestKeys = null;
+ }
}
18 years, 8 months
JBoss Rich Faces SVN: r2516 - trunk/ui/panelmenu/src/main/config/component.
by richfaces-svn-commits@lists.jboss.org
Author: vkorluzhenko
Date: 2007-08-27 14:33:45 -0400 (Mon, 27 Aug 2007)
New Revision: 2516
Modified:
trunk/ui/panelmenu/src/main/config/component/panelMenu.xml
Log:
http://jira.jboss.com/jira/browse/RF-696 - added descriptions
Modified: trunk/ui/panelmenu/src/main/config/component/panelMenu.xml
===================================================================
--- trunk/ui/panelmenu/src/main/config/component/panelMenu.xml 2007-08-27 18:32:31 UTC (rev 2515)
+++ trunk/ui/panelmenu/src/main/config/component/panelMenu.xml 2007-08-27 18:33:45 UTC (rev 2516)
@@ -175,13 +175,17 @@
<property>
<name>itemStyle</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ CSS style(s) is/are to be applied to item when this component is rendered.
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
<name>itemClass</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ Space-separated list of CSS style class(es) that are be applied to item of this component
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
@@ -199,13 +203,17 @@
<property>
<name>disabledItemClass</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ Space-separated list of CSS style class(es) that are be applied to disabled item of this component
+ </description>
<defaultvalue><![CDATA["dr-pmenu-disabled-element rich-pmenu-disabled-element"]]></defaultvalue>
</property>
<property>
<name>disabledItemStyle</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ CSS style(s) is/are to be applied to disabled item when this component is rendered.
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
@@ -250,7 +258,8 @@
<description>contain the name or the clientId of any of the item or group, the child
defined in this attribute should be highlighted on PanelMenu rendering</description>
<defaultvalue><![CDATA[""]]></defaultvalue>
- </property> &ui_component_attributes; &html_events; <property>
+ </property> &ui_component_attributes; &html_events; &ui_input_attributes;
+ &ui_output_attributes;<property>
<name>onclick</name>
<classname>java.lang.String</classname>
<description/>
@@ -265,19 +274,25 @@
<property>
<name>onmouseout</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ HTML: script expression; a pointer was moved away.
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
<name>onmousemove</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ HTML: script expression; a pointer was moved within.
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
<name>onmouseover</name>
<classname>java.lang.String</classname>
- <description/>
+ <description>
+ HTML: script expression; a pointer was moved onto.
+ </description>
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
<property>
@@ -305,6 +320,28 @@
<defaultvalue>false</defaultvalue>
</property>
+ <property>
+ <name>requiredMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the validation message for the "required" facility, if the "required"
+ facility is used </description>
+ </property>
+ <property>
+ <name>validatorMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the validator message, replacing any message that comes from the validator
+ </description>
+ </property>
+ <property>
+ <name>converterMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the converter message, replacing any message that comes from the converter
+ </description>
+ </property>
+
<property hidden="true">
<name>localValueSet</name>
<description>localValueSet</description>
@@ -397,7 +434,8 @@
immediately (that is, during Apply Request Values phase), rather than waiting until
a Process Validations phase. </description>
</property> &ui_component_attributes; &html_input_attributes;
- &html_input_events; &ui_input_attributes; &html_events; <property>
+ &html_input_events; &ui_input_attributes;
+ &ui_output_attributes; &html_events; <property>
<name>oncollapse</name>
<classname>java.lang.String</classname>
<description/>
@@ -464,6 +502,28 @@
<defaultvalue><![CDATA[""]]></defaultvalue>
</property>
+ <property>
+ <name>requiredMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the validation message for the "required" facility, if the "required"
+ facility is used </description>
+ </property>
+ <property>
+ <name>validatorMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the validator message, replacing any message that comes from the validator
+ </description>
+ </property>
+ <property>
+ <name>converterMessage</name>
+ <classname>java.lang.String</classname>
+ <description> A ValueExpression enabled attribute that, if present, will be used as the
+ text of the converter message, replacing any message that comes from the converter
+ </description>
+ </property>
+
<property hidden="true">
<name>localValueSet</name>
<description>localValueSet</description>
18 years, 8 months
JBoss Rich Faces SVN: r2515 - trunk/docs/userguide/en/src/main/docbook/included.
by richfaces-svn-commits@lists.jboss.org
Author: vkorluzhenko
Date: 2007-08-27 14:32:31 -0400 (Mon, 27 Aug 2007)
New Revision: 2515
Modified:
trunk/docs/userguide/en/src/main/docbook/included/calendar.xml
Log:
http://jira.jboss.com/jira/browse/RF-391- forums revision, improved description
http://jira.jboss.com/jira/browse/RF-396 - added relevant resources links
Modified: trunk/docs/userguide/en/src/main/docbook/included/calendar.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/calendar.xml 2007-08-27 18:31:15 UTC (rev 2514)
+++ trunk/docs/userguide/en/src/main/docbook/included/calendar.xml 2007-08-27 18:32:31 UTC (rev 2515)
@@ -83,11 +83,13 @@
<title>Details of Usage</title>
<para>The <emphasis>
<property>"popup"</property>
- </emphasis> attribute defines calendar representation mode on a page. If it's "true"
- the calendar is represented on a page as an input field and a button. Clicking on the button
- calls the calendar popup as it's shown on the picture below. </para>
+ </emphasis> attribute defines calendar representation mode on a page. If it's
+ "true" the calendar is represented on a page as an input field and a button.
+ Clicking on the button calls the calendar popup as it's shown on the picture below. </para>
<figure>
- <title>Using the <emphasis><property>"popup"</property></emphasis> attribute</title>
+ <title>Using the <emphasis>
+ <property>"popup"</property>
+ </emphasis> attribute</title>
<mediaobject>
<imageobject>
@@ -134,7 +136,7 @@
</itemizedlist>
<para> By default, the <emphasis>
<property>"direction"</property>
- </emphasis> attribute is set to "bottom-right".</para>
+ </emphasis> attribute is set to "bottom-right".</para>
<para>The possible values for the <emphasis>
<property>"jointPoint"</property>
</emphasis> are: </para>
@@ -147,7 +149,7 @@
</itemizedlist>
<para> By default, the <emphasis>
<property>"jointPoint"</property>
- </emphasis> attribute is set to "bottom-left".</para>
+ </emphasis> attribute is set to "bottom-left".</para>
<para>The <emphasis role="bold">
<property><rich:calendar></property>
</emphasis> component provides to use <emphasis>
@@ -195,6 +197,31 @@
</f:facet>
...</programlisting>
+ <para>The example of using JavaScript API is placed below:</para>
+
+ <para>
+ <emphasis role="bold">Example:</emphasis>
+ </para>
+ <programlisting role="XML"><![CDATA[...
+ <a4j:form id="form">
+ <h:panelGroup id="test" columns="2" style="width: 300px">
+ <h:selectBooleanCheckbox value="#{bean.check}">
+ <a4j:support event="onchange" reRender="test" />
+ <f:selectItem itemValue="true" itemLabel="Show" />
+ <f:selectItem itemValue="false" itemLabel="Hide" />
+ </h:selectBooleanCheckbox>
+ <rich:calendar popup="true"
+ rendered="#{!bean.check}" value="#{bean.date}" id="c"/>
+ <a onclick="$('form:c').component.doExpand()" href="#">Show</a>
+ </h:panelGroup>
+ </a4j:form>
+...
+]]></programlisting>
+
+ <para>Also the discussion about this problem can be fobnd on the <ulink
+ url="http://www.jboss.com/index.html?module=bb&op=viewtopic&p=4078301#..."
+ >RichFaces Users Forum</ulink>.</para>
+
<para>The <emphasis role="bold">
<property><rich:calendar></property>
</emphasis> component provides the possibility to use a special data model to define data for
@@ -212,15 +239,18 @@
<para>This method is called when it's necessary to represent the next block of
CalendarDataItems. It happens during navigation to the next (previous) month or in any other
- case when calendar renders. This method is called in <emphasis><property>"Ajax"</property></emphasis> mode when the
- calendar renders a new page. </para>
+ case when calendar renders. This method is called in <emphasis>
+ <property>"Ajax"</property>
+ </emphasis> mode when the calendar renders a new page. </para>
<para><emphasis role="bold">CalendarDataModelItem</emphasis> provides the following function:</para>
<itemizedlist>
<listitem>Date getDate() - returns date from the item. Default implementation returns date.</listitem>
- <listitem>Boolean isEnabled() - returns <emphasis><property>"true"</property></emphasis> if date is
- <emphasis><property>"selectable"</property></emphasis> on the calendar. Default implementation returns
- "true".</listitem>
+ <listitem>Boolean isEnabled() - returns <emphasis>
+ <property>"true"</property>
+ </emphasis> if date is <emphasis>
+ <property>"selectable"</property>
+ </emphasis> on the calendar. Default implementation returns "true".</listitem>
<listitem>String getStyleClass() - returns string appended to the style class for the date
span. For example it could be "relevant holyday". It means that the class
could be defined like the "rich-cal-day-relevant-holyday" one. Default
@@ -247,113 +277,114 @@
</thead>
<tbody>
-
+
<row>
<entry>selectDate(date)</entry>
-
- <entry>Select the date specified. If the date isn't in current month - performs request to select</entry>
+
+ <entry>Select the date specified. If the date isn't in current month - performs
+ request to select</entry>
</row>
-
+
<row>
<entry>isDateEnabled(date)</entry>
-
+
<entry>Check if given date is selectable</entry>
</row>
-
+
<row>
<entry>enableDate(date)</entry>
-
+
<entry>Enables date cell control on the calendar</entry>
</row>
-
+
<row>
<entry>disableDate(date)</entry>
-
+
<entry>Disables date cell control on the calendar</entry>
</row>
-
+
<row>
<entry>enableDates(date[])</entry>
-
+
<entry>Enables dates cell controls set on the calendar</entry>
</row>
-
+
<row>
<entry>disableDates(date[])</entry>
-
+
<entry>Disables dates cell controls set on the calendar</entry>
</row>
-
+
<row>
<entry>nextMonth()</entry>
-
+
<entry>Navigate to next month</entry>
</row>
-
+
<row>
<entry>nextYear()</entry>
-
+
<entry>Navigate to next year</entry>
</row>
-
+
<row>
<entry>prevMonth()</entry>
-
+
<entry>Navigate to previous month </entry>
</row>
-
+
<row>
<entry>prevYear()</entry>
-
+
<entry>Navigate to previous year</entry>
</row>
-
+
<row>
<entry>today()</entry>
-
+
<entry>Select today date</entry>
</row>
-
+
<row>
<entry>getSelectedDate()</entry>
-
+
<entry>Return currently selected date</entry>
</row>
-
+
<row>
<entry>Object getData()</entry>
-
+
<entry>Return additional data for the date</entry>
</row>
-
+
<row>
<entry>enable()</entry>
-
+
<entry>enables calendar</entry>
</row>
-
+
<row>
<entry>disable()</entry>
-
+
<entry>disables calendar</entry>
</row>
-
+
<row>
<entry>getCurrentMonth()</entry>
-
+
<entry>Returns number of the month currently being viewed</entry>
</row>
-
+
<row>
<entry>getCurrentYear()</entry>
-
+
<entry>Returns number of the year currently being viewed</entry>
</row>
-
+
<row>
<entry>doCollapse()</entry>
- <entry>Collapse calendar element</entry>
+ <entry>Collapse calendar element</entry>
</row>
<row>
@@ -378,4 +409,14 @@
</section-->
+ <section>
+ <title>Relevant resources links</title>
+ <para><ulink url="http://livedemo.exadel.com/richfaces-demo/richfaces/calendar.jsf?c=calendar"
+ >Here</ulink> you can see the example of <emphasis role="bold"
+ ><rich:calendar></emphasis> usage and sources for the given example. </para>
+ <para>How to use JavaScript API see on the <ulink
+ url="http://www.jboss.com/index.html?module=bb&op=viewtopic&p=4078301#..."
+ >RichFaces Users Forum</ulink>.</para>
+ </section>
+
</section>
18 years, 8 months
JBoss Rich Faces SVN: r2514 - trunk/docs/userguide/en/src/main/docbook/modules.
by richfaces-svn-commits@lists.jboss.org
Author: vkorluzhenko
Date: 2007-08-27 14:31:15 -0400 (Mon, 27 Aug 2007)
New Revision: 2514
Modified:
trunk/docs/userguide/en/src/main/docbook/modules/RFCfaq.xml
Log:
http://jira.jboss.com/jira/browse/RF-391
http://jira.jboss.com/jira/browse/RF-389 - forums revision, FAQ updated
Modified: trunk/docs/userguide/en/src/main/docbook/modules/RFCfaq.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/modules/RFCfaq.xml 2007-08-27 17:11:46 UTC (rev 2513)
+++ trunk/docs/userguide/en/src/main/docbook/modules/RFCfaq.xml 2007-08-27 18:31:15 UTC (rev 2514)
@@ -503,6 +503,31 @@
url="http://labs.jboss.com/wiki/ExpandCollapseTreeNodes"
>here</ulink>.</para>
</section>
+
+ <section>
+ <?dbhtml filename="HowtouseJavaScriptAPI.html"?>
+ <title>How to use JavaScript API?</title>
+ <para>The simple code is placed below:</para>
+ <para>
+ <emphasis role="bold">Example:</emphasis>
+ </para>
+ <programlisting role="XML"><![CDATA[...
+ <a4j:form id="form">
+ <h:panelGroup id="test" columns="2" style="width: 300px">
+ <h:selectBooleanCheckbox value="#{bean.check}">
+ <a4j:support event="onchange" reRender="test" />
+ <f:selectItem itemValue="true" itemLabel="Show" />
+ <f:selectItem itemValue="false" itemLabel="Hide" />
+ </h:selectBooleanCheckbox>
+ <rich:calendar popup="true"
+ rendered="#{!bean.check}" value="#{bean.date}" id="c"/>
+ <a onclick="$('form:c').component.doExpand()" href="#">Show</a>
+ </h:panelGroup>
+ </a4j:form>
+...
+]]></programlisting>
+ </section>
+
<section id="DecidingWhatToChangeOnTheServerSide">
<?dbhtml filename="DecidingWhatToChangeOnTheServerSide.html"?>
18 years, 8 months
JBoss Rich Faces SVN: r2513 - in trunk: framework/api/src/main/java/org/richfaces/model/selection and 4 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: maksimkaszynski
Date: 2007-08-27 13:11:46 -0400 (Mon, 27 Aug 2007)
New Revision: 2513
Added:
trunk/ui/scrollableDataTable/src/test/java/org/richfaces/component/html/AbstractScrollableDataTableTestCase.java
Modified:
trunk/cdk/generator/src/main/java/org/ajax4jsf/builder/generator/TestDataGenerator.java
trunk/framework/api/src/main/java/org/richfaces/model/selection/SimpleSelection.java
trunk/samples/scrollableDataTableDemo/src/main/webapp/pages/scrollable-grid.xhtml
trunk/ui/scrollableDataTable/pom.xml
trunk/ui/scrollableDataTable/src/main/config/component/scrollable-data-table.xml
Log:
added component unit tests to support user-defined data types
Modified: trunk/cdk/generator/src/main/java/org/ajax4jsf/builder/generator/TestDataGenerator.java
===================================================================
--- trunk/cdk/generator/src/main/java/org/ajax4jsf/builder/generator/TestDataGenerator.java 2007-08-27 15:55:56 UTC (rev 2512)
+++ trunk/cdk/generator/src/main/java/org/ajax4jsf/builder/generator/TestDataGenerator.java 2007-08-27 17:11:46 UTC (rev 2513)
@@ -116,16 +116,28 @@
}
private String getTestData(String propertyName, String className, int number) {
+
String string = number == 0 ? testData.get(className) : testData1.get(className);
+
if (string != null) {
return string;
}
-
- if (number == 0) {
- return "\"" + propertyName + "\"";
+
+ try {
+ Class<?> clazz = Class.forName(className);
+ if (clazz.isAssignableFrom(String.class)) {
+ if (number == 0) {
+ return "\"" + propertyName + "\"";
+ } else {
+ return "\"" + propertyName + "_" + propertyName + "\"";
+ }
+ }
+
+ } catch(Exception e) {
+
}
-
- return "\"" + propertyName + "_" + propertyName + "\"";
+
+ return "createTestData_" + propertyName + "()";
}
public String getTestData(PropertyBean propertyBean) {
Modified: trunk/framework/api/src/main/java/org/richfaces/model/selection/SimpleSelection.java
===================================================================
--- trunk/framework/api/src/main/java/org/richfaces/model/selection/SimpleSelection.java 2007-08-27 15:55:56 UTC (rev 2512)
+++ trunk/framework/api/src/main/java/org/richfaces/model/selection/SimpleSelection.java 2007-08-27 17:11:46 UTC (rev 2513)
@@ -40,4 +40,29 @@
public void clear() {
keys.clear();
}
+
+ public int hashCode() {
+ final int prime = 31;
+ int result = 1;
+ result = prime * result + ((keys == null) ? 0 : keys.hashCode());
+ return result;
+ }
+
+ public boolean equals(Object obj) {
+ if (this == obj)
+ return true;
+ if (obj == null)
+ return false;
+ if (getClass() != obj.getClass())
+ return false;
+ final SimpleSelection other = (SimpleSelection) obj;
+ if (keys == null) {
+ if (other.keys != null)
+ return false;
+ } else if (!keys.equals(other.keys))
+ return false;
+ return true;
+ }
+
+
}
Modified: trunk/samples/scrollableDataTableDemo/src/main/webapp/pages/scrollable-grid.xhtml
===================================================================
--- trunk/samples/scrollableDataTableDemo/src/main/webapp/pages/scrollable-grid.xhtml 2007-08-27 15:55:56 UTC (rev 2512)
+++ trunk/samples/scrollableDataTableDemo/src/main/webapp/pages/scrollable-grid.xhtml 2007-08-27 17:11:46 UTC (rev 2513)
@@ -26,6 +26,10 @@
height: 30px;
}
+ .col {
+ color: red;
+ }
+
</style>
</head>
@@ -46,6 +50,7 @@
first="0"
rows="40"
width="800px"
+ columnClasses="col"
height="500px" hideWhenScrolling="false">
Modified: trunk/ui/scrollableDataTable/pom.xml
===================================================================
--- trunk/ui/scrollableDataTable/pom.xml 2007-08-27 15:55:56 UTC (rev 2512)
+++ trunk/ui/scrollableDataTable/pom.xml 2007-08-27 17:11:46 UTC (rev 2513)
@@ -22,7 +22,15 @@
<goal>generate</goal>
</goals>
</execution>
+ <execution>
+ <id>generate-test-sources</id>
+ <phase>generate-test-sources</phase>
+ <goals>
+ <goal>generate-tests</goal>
+ </goals>
+ </execution>
</executions>
+
<configuration>
<library>
<prefix>org.richfaces</prefix>
Modified: trunk/ui/scrollableDataTable/src/main/config/component/scrollable-data-table.xml
===================================================================
--- trunk/ui/scrollableDataTable/src/main/config/component/scrollable-data-table.xml 2007-08-27 15:55:56 UTC (rev 2512)
+++ trunk/ui/scrollableDataTable/src/main/config/component/scrollable-data-table.xml 2007-08-27 17:11:46 UTC (rev 2513)
@@ -17,6 +17,10 @@
<description>
<![CDATA[ Scrollable Data Table ]]>
</description>
+ <test>
+ <classname>org.richfaces.component.html.HtmlScrollableDataTableComponentTest</classname>
+ <superclassname>org.richfaces.component.html.AbstractScrollableDataTableTestCase</superclassname>
+ </test>
<renderer generate="true" override="true">
<name>org.richfaces.renderkit.html.ScrollableDataTableRenderer</name>
@@ -28,12 +32,10 @@
<superclass>
org.ajax4jsf.webapp.taglib.HtmlComponentTagBase
</superclass>
- <!--
- <test>
+ <!--test>
<classname>org.richfaces.taglib.ScrollableDataTableTagTest</classname>
<superclassname>org.ajax4jsf.tests.AbstractAjax4JsfTestCase</superclassname>
- </test>
- -->
+ </test-->
</tag>
<property>
@@ -107,7 +109,7 @@
<classname>java.lang.String</classname>
</property>
- <property attachedstate="true" hidden="true">
+ <property attachedstate="true">
<name>sortOrder</name>
<classname>org.richfaces.model.SortOrder</classname>
</property>
Added: trunk/ui/scrollableDataTable/src/test/java/org/richfaces/component/html/AbstractScrollableDataTableTestCase.java
===================================================================
--- trunk/ui/scrollableDataTable/src/test/java/org/richfaces/component/html/AbstractScrollableDataTableTestCase.java (rev 0)
+++ trunk/ui/scrollableDataTable/src/test/java/org/richfaces/component/html/AbstractScrollableDataTableTestCase.java 2007-08-27 17:11:46 UTC (rev 2513)
@@ -0,0 +1,51 @@
+/**
+ * License Agreement.
+ *
+ * JBoss RichFaces 3.0 - Ajax4jsf Component Library
+ *
+ * Copyright (C) 2007 Exadel, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License version 2.1 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+package org.richfaces.component.html;
+
+import org.ajax4jsf.tests.AbstractAjax4JsfTestCase;
+import org.richfaces.model.SortOrder;
+import org.richfaces.model.selection.Selection;
+import org.richfaces.model.selection.SimpleSelection;
+
+/**
+ * @author Maksim Kaszynski
+ *
+ */
+public class AbstractScrollableDataTableTestCase extends AbstractAjax4JsfTestCase {
+
+ /**
+ * @param name
+ */
+ public AbstractScrollableDataTableTestCase(String name) {
+ super(name);
+
+ }
+
+
+ protected SortOrder createTestData_sortOrder() {
+ return new SortOrder();
+ }
+
+ protected Selection createTestData_selection() {
+ return new SimpleSelection();
+ }
+}
18 years, 8 months
JBoss Rich Faces SVN: r2512 - trunk/ui/scrollableDataTable/src/main/java/org/richfaces/renderkit/html.
by richfaces-svn-commits@lists.jboss.org
Author: konstantin.mishin
Date: 2007-08-27 11:55:56 -0400 (Mon, 27 Aug 2007)
New Revision: 2512
Modified:
trunk/ui/scrollableDataTable/src/main/java/org/richfaces/renderkit/html/ScrollableDataTableBaseRenderer.java
Log:
RF-693
Modified: trunk/ui/scrollableDataTable/src/main/java/org/richfaces/renderkit/html/ScrollableDataTableBaseRenderer.java
===================================================================
--- trunk/ui/scrollableDataTable/src/main/java/org/richfaces/renderkit/html/ScrollableDataTableBaseRenderer.java 2007-08-27 15:15:14 UTC (rev 2511)
+++ trunk/ui/scrollableDataTable/src/main/java/org/richfaces/renderkit/html/ScrollableDataTableBaseRenderer.java 2007-08-27 15:55:56 UTC (rev 2512)
@@ -686,7 +686,7 @@
int index = grid.getFirst();
int startRow = ScrollableDataTableUtils.getClientRowIndex(grid);
- int count = grid.getRows();
+ int count = grid.getRows( )== 0 ? grid.getRowCount() : grid.getRows();
ScrollableDataTableScrollData options = new ScrollableDataTableScrollData(index, startRow, count);
18 years, 8 months
JBoss Rich Faces SVN: r2511 - in trunk/ui/calendar: design/calendar-js and 2 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: akushunin
Date: 2007-08-27 11:15:14 -0400 (Mon, 27 Aug 2007)
New Revision: 2511
Modified:
trunk/ui/calendar/design/calendar-js/calendar-prototype.js
trunk/ui/calendar/design/calendar/calendar_div.html
trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/css/calendar.xcss
trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js
Log:
some fixes after classes refactoring
Modified: trunk/ui/calendar/design/calendar/calendar_div.html
===================================================================
--- trunk/ui/calendar/design/calendar/calendar_div.html 2007-08-27 15:15:07 UTC (rev 2510)
+++ trunk/ui/calendar/design/calendar/calendar_div.html 2007-08-27 15:15:14 UTC (rev 2511)
@@ -86,7 +86,7 @@
color : #ff7800; /*unknown parameter - need to add*/
}
-.rich-calendar-current{
+.rich-calendar-today{
background-color : #ff7800; /*unknown parameter - need to add*/
color : #ffebda; /*unknown parameter - need to add*/
font-weight : bold;
@@ -235,7 +235,7 @@
<td class="rich-cell-size rich-calendar-cell rich-calendar-btn">
7<br>
</td>
- <td class="rich-cell-size rich-calendar-cell rich-calendar-current rich-calendar-btn">
+ <td class="rich-cell-size rich-calendar-cell rich-calendar-today rich-calendar-btn">
8<br>
</td>
<td class="rich-cell-size rich-calendar-cell rich-calendar-btn">
Modified: trunk/ui/calendar/design/calendar-js/calendar-prototype.js
===================================================================
--- trunk/ui/calendar/design/calendar-js/calendar-prototype.js 2007-08-27 15:15:07 UTC (rev 2510)
+++ trunk/ui/calendar/design/calendar-js/calendar-prototype.js 2007-08-27 15:15:14 UTC (rev 2511)
@@ -129,7 +129,7 @@
var weekDayHtml = this.params.weekDayMarkup( {weekDay: this.params.weekDayLabels[weekDayCounter]} );
if (weekDayCounter==6) weekDayCounter=0; else weekDayCounter++;
- htmlTextWeekDayBar+='<td id="'+this.params.weekDayBarId+i+'" class="'+(i==this.firstWeekendDayNumber || i==this.secondWeekendDayNumber ? "rich-Weekendclass" : "rich-Dayclass")+'">'+weekDayHtml+'</td>';
+ htmlTextWeekDayBar+='<td id="'+this.params.weekDayBarId+i+'" class="'+(i==this.firstWeekendDayNumber || i==this.secondWeekendDayNumber ? "Weekendclass" : "Dayclass")+'">'+weekDayHtml+'</td>';
}
htmlTextWeekDayBar+='</tr>\n';
@@ -189,9 +189,9 @@
{
this.selectedDate=new Date(this.currentDate);
this.selectedDate.setDate(obj.data);
- if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "rich-Selectedrich-Dayclass");
+ if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "Selecteddayclass");
this.selectedDateElement = obj;
- Element.addClassName(obj, "rich-Selectedrich-Dayclass");
+ Element.addClassName(obj, "Selecteddayclass");
$('div_'+this.params.dayListTableId+'_selected_date').innerHTML=obj.data+"/"+(this.currentDate.getMonth()+1)+"/"+this.currentDate.getFullYear();
} else {
@@ -280,7 +280,7 @@
this.days = [];
var dayCounter = previousMonthDays - wd + 1;
// previuos month days
- if (wd>0) while (dayCounter<=previousMonthDays) {this.days.push({day:dayCounter, _isWeekend: this.isWeekend(p), _month:-1, _className:"rich-Disabledrich-Dayclass"}); dayCounter++; p++; }
+ if (wd>0) while (dayCounter<=previousMonthDays) {this.days.push({day:dayCounter, _isWeekend: this.isWeekend(p), _month:-1, _className:"Disableddayclass"}); dayCounter++; p++; }
dayCounter = 1;
// current month days
@@ -291,9 +291,9 @@
while (dayCounter<firstDay)
{
if (this.isWeekend(p%7))
- this.days.push({day:dayCounter, _isWeekend: true, _month:0, _className:"rich-Weekendrich-Dayclass", _hoverClassName:"rich-Hoveredweekclass"});
+ this.days.push({day:dayCounter, _isWeekend: true, _month:0, _className:"Weekenddayclass", _hoverClassName:"Hoveredweekclass"});
else
- this.days.push({day:dayCounter, _isWeekend: false, _month:0, _className:"rich-Commonrich-Dayclass", _hoverClassName:"rich-Hoveredrich-Dayclass"});
+ this.days.push({day:dayCounter, _isWeekend: false, _month:0, _className:"Commondayclass", _hoverClassName:"Hovereddayclass"});
dayCounter++;
p++;
@@ -308,8 +308,8 @@
obj = this.daysData.days[idx];
obj._isWeekend = flag;
obj._month = 0;
- if (flag) {obj._className = "rich-Weekendrich-Dayclass"; obj._hoverClassName = "rich-Hoveredweekclass";}
- else {obj._className = "rich-Commonrich-Dayclass"; obj._hoverClassName = "rich-Hoveredrich-Dayclass";}
+ if (flag) {obj._className = "Weekenddayclass"; obj._hoverClassName = "Hoveredweekclass";}
+ else {obj._className = "Commondayclass"; obj._hoverClassName = "Hovereddayclass";}
this.days.push(obj);
idx++;
dayCounter++;
@@ -319,9 +319,9 @@
while (dayCounter<=currentMonthDays)
{
if (this.isWeekend(p%7))
- this.days.push({day:dayCounter, _isWeekend: true, _month:0, _className:"rich-Weekendrich-Dayclass", _hoverClassName:"rich-Hoveredweekclass"});
+ this.days.push({day:dayCounter, _isWeekend: true, _month:0, _className:"Weekenddayclass", _hoverClassName:"Hoveredweekclass"});
else
- this.days.push({day:dayCounter, _isWeekend: false, _month:0, _className:"rich-Commonrich-Dayclass", _hoverClassName:"rich-Hoveredrich-Dayclass"});
+ this.days.push({day:dayCounter, _isWeekend: false, _month:0, _className:"Commondayclass", _hoverClassName:"Hovereddayclass"});
dayCounter++;
p++;
}
@@ -329,7 +329,7 @@
// next month days
var ld = 7-p%7;
- if (ld!=7) while (dayCounter<=ld) { this.days.push({day:dayCounter++, _isWeekend: this.isWeekend(p%7), _month:1, _className:"rich-Disabledrich-Dayclass"}); }
+ if (ld!=7) while (dayCounter<=ld) { this.days.push({day:dayCounter++, _isWeekend: this.isWeekend(p%7), _month:1, _className:"Disableddayclass"}); }
// render
p=0;
@@ -361,8 +361,8 @@
if (dataobj) {
element.data=dataobj.day;
element.innerHTML = this.params.dayListMarkupArray[p]( dataobj );
- element.className = dataobj._className + (todayflag /*&& dataobj._month==0 */&& dataobj.day==todaydate ? " rich-Torich-Dayclass" : "");
- if (selectedflag && dataobj._month==0 && dataobj.day==selecteddate) { this.selectedDateElement = element; element.className+=" rich-Selectedrich-Dayclass"; }
+ element.className = dataobj._className + (todayflag /*&& dataobj._month==0 */&& dataobj.day==todaydate ? " Todayclass" : "");
+ if (selectedflag && dataobj._month==0 && dataobj.day==selecteddate) { this.selectedDateElement = element; element.className+=" Selecteddayclass"; }
this.setCellEvents(element);
p++;
} else {
Modified: trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/css/calendar.xcss
===================================================================
--- trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/css/calendar.xcss 2007-08-27 15:15:07 UTC (rev 2510)
+++ trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/css/calendar.xcss 2007-08-27 15:15:14 UTC (rev 2511)
@@ -67,7 +67,7 @@
color : #ff7800; /*unknown parameter - need to add*/
}*/
-/*.rich-calendar-current{
+/*.rich-calendar-today{
background-color : #ff7800; /*unknown parameter - need to add*/
color : #ffebda; /*unknown parameter - need to add*/
font-weight : bold;
@@ -154,7 +154,7 @@
<u:style name="font-family" skin="generalFamilyFont"/>
</u:selector>
- <u:selector name=".rich-Weekendclass">
+ <u:selector name=".Weekendclass">
<u:style name="color" value="red"/>
</u:selector>
@@ -174,7 +174,7 @@
</u:selector>
/*
-.rich-calendar-current{
+.rich-calendar-today{
background-color : #ff7800; /*unknown parameter - need to add
color : #ffebda; /*unknown parameter - need to add
font-weight : bold;
@@ -189,7 +189,7 @@
<u:style name="color" value="#a0a0a0"/> /*unknown parameter - need to add*/
</u:selector>
- <u:selector name=".rich-calendar-current">
+ <u:selector name=".rich-calendar-today">
<u:style name="background-color" value="#ff7800"/> /*unknown parameter - need to add*/
<u:style name="color" value="#ffebda"/> /*unknown parameter - need to add*/
<u:style name="font-weight" value="bold"/>
@@ -205,7 +205,7 @@
<u:style name="background-color" value="#f3f3f3"/> /*unknown parameter - need to add*/
</u:selector>
- <u:selector name=".rich-calendar-current.rich-calendar-hover">
+ <u:selector name=".rich-calendar-today.rich-calendar-hover">
<u:style name="color" value="#ff7800"/> /*unknown parameter - need to add*/
</u:selector>
Modified: trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.desc.xml 2007-08-27 14:27:47 UTC (rev 2509)
+++ trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.desc.xml 2007-08-27 15:15:07 UTC (rev 2510)
@@ -1,35 +1,38 @@
<?xml version="1.0" encoding="UTF-8"?>
<section>
-<sectioninfo>
-<keywordset>
- <keyword>scrollableDataTable</keyword>
-</keywordset>
-</sectioninfo>
-<section>
-<title>Description</title>
- <para>The <emphasis role="bold">
- <property><rich:scrollableDataTable></property>
- </emphasis> component is used to represent the tabular data.</para>
- <figure>
- <title><rich:scrollableDataTable> component</title>
+ <sectioninfo>
+ <keywordset>
+ <keyword>scrollableDataTable</keyword>
+ </keywordset>
+ </sectioninfo>
+ <section>
+ <title>Description</title>
+ <para>
+ The <property><rich:scrollableDataTable></property> component is used for the table-like component creation.
+ The component just adds the set of additional features described below in comparison with the standard table.
+ </para>
+
+ <figure>
+ <title>ScrollableDataTable component</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/scrollableDataTable.png"/>
+ <imagedata fileref="images/scrollable-dt1.png"/>
</imageobject>
</mediaobject>
</figure>
+
+ </section>
+ <section>
+ <title>Key Features</title>
+ <itemizedlist>
+ <listitem>Highly customizable look and feel</listitem>
+ <listitem>Variable content of the table cells</listitem>
+ <listitem>Dynamically fetching the rows from the server when the table is scrolled up and down</listitem>
+ <listitem>Resizing columns by mouse dragging the column bar</listitem>
+ <listitem>Sorting column by clicking the header</listitem>
+ <listitem>Fixed one or more left columns when table is scrolled horizontally</listitem>
+ <listitem>One and multi-selection rows mode</listitem>
+ <listitem>Built-it drag-n-drop support</listitem>
+ </itemizedlist>
</section>
- <section>
- <title>Key Features</title>
- <itemizedlist>
- <listitem>Highly customizable look and feel</listitem>
- <listitem>Variable content of the table cells</listitem>
- <listitem>Dynamically fetching the rows from the server when the table is scrolled up and down</listitem>
- <listitem>Resizing columns by mouse dragging the column bar</listitem>
- <listitem>Sorting column by clicking the header</listitem>
- <listitem>Fixed one or more left columns when table is scrolled horizontally</listitem>
- <listitem>One and multi-selection rows mode</listitem>
- <listitem>Built-it drag-n-drop support</listitem>
- </itemizedlist>
</section>
-</section>
\ No newline at end of file
Modified: trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.xml 2007-08-27 14:27:47 UTC (rev 2509)
+++ trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.xml 2007-08-27 15:15:07 UTC (rev 2510)
@@ -67,6 +67,70 @@
...
]]></programlisting>
</section>
+
+ <section>
+ <title>Details of Usage</title>
+ <para>
+ The component represents on a page as a scrollable table with some fixed (non-scrollable) rows (header, footer) and columns.
+ Columns of the table are optionally resizable. Resizing is available using "drag and drop" of the column vertical borders.
+ There is possibility to expand or collapse the columns through JS API on the client side.
+ User can define the number of the fixed columns from the left side using attribute <emphasis><property>"frozenColCount"</property></emphasis> that will not be scrolled
+ via horizontal scroll.
+ </para>
+
+ <para>
+ It's possible to select the whole row with onclick on the row or some set of rows. Selection is optional and availability of such feature
+ is defined on the component.
+ There are two ways to select a few rows:
+ <itemizedlist>
+ <listitem>Just clicking the columns one by one.</listitem>
+ <listitem>Clicking some row with the SHIFT button hold.
+ In this case all the rows starting from last selected up to clicked should be selected.</listitem>
+ </itemizedlist>
+ </para>
+
+ <para>
+ The columns provides the possibility of expanding/collapsing on the client side through the next JS API:
+
+ <itemizedlist>
+ <listitem>doCollapse(columnId) - Performs the collapse action for the column with the corresponding id</listitem>
+ </itemizedlist>
+
+ It's possible to sort the table content after clicks on the header. The feature is optional.
+ Every column should be pointed to the comparator method that will be used for sorting the table.
+
+ In case the <property><rich:scrollableDataTable></property> is already sorted by some
+ column and the header of this column has been clicked again - the sorting will be
+ reversed.
+ </para>
+
+<para>
+ <emphasis role="bold">Those a the typical variants of using:</emphasis>
+</para>
+ <programlisting role="XML"><![CDATA[...
+<rich:scrollableDataTable value="#{modelBuilder.model}" var="issues"
+ frozenColCount="1"
+ first="0"
+ rows="40"
+ width="300px"
+ height="396px">
+
+ <rich:column width="100px">
+ <f:facet name="header" >
+ <h:outputText value="State"/>
+ </f:facet>
+ <h:outputText value="#{issues.cell1}"/>
+ <f:facet name="footer">
+ <h:outputText value="State"/>
+ </f:facet>
+ </rich:column>
+ <!--...//Set of columns and header/footer facets-->
+</rich:scrollableDataTable>
+...
+]]></programlisting>
+
+ </section>
+
<!--section>
<title>Details of Usage</title>
<para>The <property>table</property> component is very similar to the custom JSF dataTable one,
Added: trunk/docs/userguide/en/src/main/resources/images/scrollable-dt1.png
===================================================================
(Binary files differ)
Property changes on: trunk/docs/userguide/en/src/main/resources/images/scrollable-dt1.png
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
18 years, 8 months
JBoss Rich Faces SVN: r2509 - in trunk/ui/scrollableDataTable/src/main: resources/org/richfaces/renderkit/html/css and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: konstantin.mishin
Date: 2007-08-27 10:27:47 -0400 (Mon, 27 Aug 2007)
New Revision: 2509
Modified:
trunk/ui/scrollableDataTable/src/main/javascript/ClientUI/controls/grid/GridHeader.js
trunk/ui/scrollableDataTable/src/main/resources/org/richfaces/renderkit/html/css/scrollable-data-table.xcss
Log:
RF-689
Modified: trunk/ui/scrollableDataTable/src/main/javascript/ClientUI/controls/grid/GridHeader.js
===================================================================
--- trunk/ui/scrollableDataTable/src/main/javascript/ClientUI/controls/grid/GridHeader.js 2007-08-27 13:34:00 UTC (rev 2508)
+++ trunk/ui/scrollableDataTable/src/main/javascript/ClientUI/controls/grid/GridHeader.js 2007-08-27 14:27:47 UTC (rev 2509)
@@ -341,6 +341,9 @@
this.dragColumnInfo.mouseDown = false;
var delta = Event.pointerX(event) - this.dragColumnInfo.startX;
var newWidth = this.dragColumnInfo.object.getWidth() + delta;
+ if(newWidth < this.dragColumnInfo.minWidth) {
+ newWidth = this.dragColumnInfo.minWidth;
+ }
setTimeout(function() {
this.grid.adjustColumnWidth(this.dragColumnInfo.srcElement.columnIndex, newWidth);
}.bind(this), 10);
Modified: trunk/ui/scrollableDataTable/src/main/resources/org/richfaces/renderkit/html/css/scrollable-data-table.xcss
===================================================================
--- trunk/ui/scrollableDataTable/src/main/resources/org/richfaces/renderkit/html/css/scrollable-data-table.xcss 2007-08-27 13:34:00 UTC (rev 2508)
+++ trunk/ui/scrollableDataTable/src/main/resources/org/richfaces/renderkit/html/css/scrollable-data-table.xcss 2007-08-27 14:27:47 UTC (rev 2509)
@@ -95,7 +95,6 @@
*/
.dr-sdt-hcbody {
cursor: default;
- padding: 3px 5px;
white-space: nowrap;
position: relative;
display: block;
18 years, 8 months
JBoss Rich Faces SVN: r2508 - in trunk/docs/userguide/en/src/main/docbook: modules and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: sabrashevich
Date: 2007-08-27 09:34:00 -0400 (Mon, 27 Aug 2007)
New Revision: 2508
Modified:
trunk/docs/userguide/en/src/main/docbook/included/loadScript.xml
trunk/docs/userguide/en/src/main/docbook/included/loadStyle.xml
trunk/docs/userguide/en/src/main/docbook/included/page.xml
trunk/docs/userguide/en/src/main/docbook/included/panel.xml
trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml
trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml
trunk/docs/userguide/en/src/main/docbook/included/portlet.xml
trunk/docs/userguide/en/src/main/docbook/included/support.xml
trunk/docs/userguide/en/src/main/docbook/included/tabPanel.xml
trunk/docs/userguide/en/src/main/docbook/included/toggleControl.xml
trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml
trunk/docs/userguide/en/src/main/docbook/included/tree.xml
trunk/docs/userguide/en/src/main/docbook/included/treeNode.xml
trunk/docs/userguide/en/src/main/docbook/modules/RFCarchitectover.xml
Log:
http://jira.jboss.com/jira/browse/RF-638?page=all links are corrected
Modified: trunk/docs/userguide/en/src/main/docbook/included/loadScript.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/loadScript.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/loadScript.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -55,7 +55,7 @@
<section>
<title>Key attributes and ways of usage</title>
<para>
- As it was mentioned <link linkend="loadScript">before</link> this componment returns its value passing it to the
+ As it was mentioned <link linkend="loadScript">above</link> this component returns its value passing it to the
getResourceUR() method of the ViewHandler for this application, and passing
the result through the encodeResourceURL() method of the ExternalContext.
</para>
Modified: trunk/docs/userguide/en/src/main/docbook/included/loadStyle.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/loadStyle.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/loadStyle.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -55,7 +55,7 @@
<section>
<title>Key attributes and ways of usage</title>
<para>
- As it was mentioned <link linkend="loadStyle">before</link> this componment returns its value passing it to the
+ As it was mentioned <link linkend="loadStyle">above</link> this component returns its value passing it to the
getResourceUR() method of the ViewHandler for this application, and passing
the result via the encodeResourceURL() method of the ExternalContext.
</para>
@@ -65,7 +65,7 @@
</para>
<para>
Except this - you may be free to put your stylesheet links right from the child
- page while using <property>facelets templates</property> .
+ page while using <property>facelets templates</property>.
</para>
</section>
Modified: trunk/docs/userguide/en/src/main/docbook/included/page.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/page.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/page.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -34,7 +34,7 @@
<section>
<title>Creating on a page</title>
<para>This component should be defined as a child component for <emphasis role="bold">
- <property><f:view></property>
+ <property><f:view>:</property>
</emphasis></para>
<programlisting role="XML"><![CDATA[<f:view>
<a4j:page>
Modified: trunk/docs/userguide/en/src/main/docbook/included/panel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panel.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/panel.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -139,7 +139,7 @@
</imageobject>
</mediaobject>
</figure>
- <para>As it has been mentioned above, the component is mostly used for a page style definition,
+ <para>As it has been mentioned <link linkend="panel">above</link>, the component is mostly used for a page style definition,
hence the main attributes are style ones.</para>
<itemizedlist>
<listitem> styleClass and style </listitem>
Modified: trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/panelBar.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -76,7 +76,7 @@
</section>
<section>
<title>Details of Usage</title>
- <para>As it was mentioned above, <property>panelBar</property> is used for grouping any
+ <para>As it was mentioned <link linkend="panelBar">above</link>, <property>panelBar</property> is used for grouping any
content on the client, thus its customization deals only with specification of sizes and
styles for rendering.</para>
<para><emphasis>
Modified: trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/panelBarItem.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -89,7 +89,7 @@
</rich:panelBarItem>
...
]]></programlisting>
- <para>As it was mentioned above, <property>panelBarItem</property> is used for grouping any
+ <para>As it was mentioned <link linkend="panelBarItem">above</link>, <property>panelBarItem</property> is used for grouping any
content inside within one <property>panelBar</property>, thus its customization deals only
with specification of sizes and styles for rendering.</para>
<para><property>panelBar</property> could contain any number of child
Modified: trunk/docs/userguide/en/src/main/docbook/included/portlet.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/portlet.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/portlet.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -1,4 +1,4 @@
-<?xml version='1.0' encoding='UTF-8'?>
+<?xml version='1.0' encoding='UTF-8'?>
<chapter>
<table>
@@ -51,7 +51,7 @@
<title>Key attributes and ways of usage</title>
<para>
Portal page can include some instances of the same portlet but clientId of elements should be different for each window.
- In that case 'namespace' is used for each portlet. The <emphasis role="bold"><property><a4j:portlet></property></emphasis>
+ In that case 'namespace' is used for each portlet. The <emphasis role="bold"><property><a4j:portlet></property></emphasis>
implemets NaimingContainer interface and adds namespace to all componets on a page.
All portlet content should be wrapped by <emphasis role="bold"><property><a4j:portlet></property></emphasis> for resolving problems mentioned
before.
Modified: trunk/docs/userguide/en/src/main/docbook/included/support.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/support.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/support.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -145,7 +145,7 @@
</h:inputText>
<h:outputText value="#{person.name}" id="test"/>
</form>]]></programlisting>
- <para>This example clearly shows mentioned <ulink url="index.html#support">above</ulink> attributes. If quick typing in a text field happens, every next requests sending is delayed for a second and requests quantity is reduced. The requests are kept in the queue" till its the sending.
+ <para>This example clearly shows mentioned above attributes. If quick typing in a text field happens, every next requests sending is delayed for a second and requests quantity is reduced. The requests are kept in the queue till its the sending.
Moreover, if the next request is already sent, the rerendering after the previous request is banned, and
it helps to avoid unnecessary processing on the client.</para>
</listitem>
Modified: trunk/docs/userguide/en/src/main/docbook/included/tabPanel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/tabPanel.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/tabPanel.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -73,7 +73,7 @@
</section>
<section>
<title>Details of Usage</title>
- <para>As it was mentioned above, <property>TabPanel</property> groups content on panels and
+ <para>As it was mentioned <link linkend="tabPanel">above</link>, <property>TabPanel</property> groups content on panels and
performs switching from one to another. Hence, modes of switching between panels are described
first of all.</para>
<note><title>Note:</title> All <property>tabPanels</property> should be wrapped into a form
Modified: trunk/docs/userguide/en/src/main/docbook/included/toggleControl.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/toggleControl.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/toggleControl.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -73,7 +73,7 @@
</section>
<section>
<title>Details of Usage</title>
- <para>As it was mentioned above, the <property>control</property> could be in any place in
+ <para>As it was mentioned <link linkend="toggleControl">above</link>, the <property>control</property> could be in any place in
layout and linked to a switching panel that is managed with <emphasis
><property>"for"</property></emphasis> attribute (in the <emphasis
Modified: trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/togglePanel.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -78,7 +78,7 @@
</section>
<section>
<title>Details of Usage</title>
- <para>As it was mentioned above, <property>togglePanel</property> splits content into named
+ <para>As it was mentioned <link linkend="togglePanel">above</link>, <property>togglePanel</property> splits content into named
facets that become rendered and processed when a click performed on controls linked to this
<property>togglePanel</property> (either switched on the client or send requests on the
server for switching).</para>
Modified: trunk/docs/userguide/en/src/main/docbook/included/tree.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/tree.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/tree.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -70,7 +70,7 @@
</section>
<section>
<title>Details of Usage</title>
- <para>As it has been mentioned above the tree component allows to render any tree-like structure
+ <para>As it has been mentioned <link linkend="tree">above</link> the tree component allows to render any tree-like structure
of data.</para>
<para>A bean property is passed into a tree <property>value</property> attribute. The property
keeps the structure of a org.richfaces.component.TreeNode type (you could have a look at this
Modified: trunk/docs/userguide/en/src/main/docbook/included/treeNode.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/included/treeNode.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/included/treeNode.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -107,7 +107,7 @@
</section>
<section>
<title>Look-and-Feel Customization</title>
- <para>As it has been mentioned above, <property>treeNode</property> defines a template for nodes
+ <para>As it has been mentioned <link linkend="treeNode">above</link>, <property>treeNode</property> defines a template for nodes
rendering in a tree. Thus, during XML document rendering (a web.xml application) as a tree,
the following nodes output (passed via var="data" on a tree) happens:</para>
Modified: trunk/docs/userguide/en/src/main/docbook/modules/RFCarchitectover.xml
===================================================================
--- trunk/docs/userguide/en/src/main/docbook/modules/RFCarchitectover.xml 2007-08-27 13:24:45 UTC (rev 2507)
+++ trunk/docs/userguide/en/src/main/docbook/modules/RFCarchitectover.xml 2007-08-27 13:34:00 UTC (rev 2508)
@@ -268,11 +268,11 @@
<section id="RequestErrorsAndSessionExpirationHandling">
<?dbhtml filename="RequestErrorsAndSessionExpirationHandling.html"?>
<title>Request Errors and Session Expiration Handling</title>
- <para>RichFaces allows to redefine standard handlers responsible for processing of different exceptional situations. It helps to define own JavaScript, which is executed when this situations occur.</para>
+ <para>RichFaces allows to redefine standard handlers responsible for processing of different exceptional situations. It helps to define own JavaScript, which is executed when these situations occur.</para>
<section id="RequestErrorsHandling">
<?dbhtml filename="RequestErrorsHandling.html"?>
<title>Request Errors Handling</title>
- <para>To execute your own code on the client in case of an error during Ajax request, it's necessary to redefine the standard "A4J.AJAX.onError " method:</para>
+ <para>To execute your own code on the client in case of an error during Ajax request, it's necessary to redefine the standard "A4J.AJAX.onError" method:</para>
<programlisting role="JAVA"><![CDATA[A4J.AJAX.onError = function(req,status,message) {
// Custom Developer Code
};]]></programlisting>
18 years, 8 months
--- trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js 2007-08-27 15:15:07 UTC (rev 2510)
+++ trunk/ui/calendar/src/main/resources/org/richfaces/renderkit/html/scripts/calendar.js 2007-08-27 15:15:14 UTC (rev 2511)
@@ -492,7 +492,7 @@
if (weekDayCounter==6) weekDayCounter=0; else weekDayCounter++;
styleClass = "rich-calendar-days";
- if (i==this.firstWeekendDayNumber || i==this.secondWeekendDayNumber) styleClass += " rich-Weekendclass";
+ if (i==this.firstWeekendDayNumber || i==this.secondWeekendDayNumber) styleClass += " Weekendclass";
if (i==6) styleClass += " rich-right-cell";
htmlTextWeekDayBar+='<td class="'+styleClass+'">'+weekDayHtml+'</td>';
@@ -733,9 +733,9 @@
{
this.selectedDate=new Date(this.currentDate);
this.selectedDate.setDate(obj.data);
- if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "rich-Selectedrich-Dayclass");
+ if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "rich-Selected Dayclass");
this.selectedDateElement = obj;
- Element.addClassName(obj, "rich-Selectedrich-Dayclass");
+ Element.addClassName(obj, "rich-Selected Dayclass");
$(this.INPUT_DATE_ID).value=this.getSelectedDateString(this.params.datePattern);
this.renderHeader();
@@ -920,7 +920,7 @@
//var _d=new Date();
if (this.selectedDateElement) {
- Element.classNames(this.selectedDateElement).remove("rich-Selectedrich-Dayclass");
+ Element.classNames(this.selectedDateElement).remove("rich-Selected Dayclass");
this.selectedDateElement = null;
}
@@ -966,21 +966,21 @@
e.add('rich-calendar-btn');
}
// TODO make some optimization with rich-calendar-current class
if (todayflag && dataobj._month==0 && dataobj.day==todaydate)
{
this.todayCellId = element.id;
this.todayCellColor = Element.getStyle(element, 'background-color').parseColor();
- e.add("rich-calendar-current");
+ e.add("rich-calendar-today");
}
else
{
- e.remove("rich-calendar-current");
+ e.remove("rich-calendar-today");
}
if (selectedflag && dataobj._month==0 && dataobj.day==selecteddate) {
this.selectedDateElement = element;
- e.add("rich-Selectedrich-Dayclass");
+ e.add("rich-Selected Dayclass");
}
this.setCellEvents(element);
@@ -1133,7 +1133,7 @@
}
else
{
- if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "rich-Selectedrich-Dayclass");
+ if (this.selectedDateElement) Element.removeClassName(this.selectedDateElement, "rich-Selected Dayclass");
if (oldSelectedDate!=null) if (noUpdate) this.render(); else this.onUpdate();
this.today(noUpdate);
}
@@ -966,21 +966,21 @@
e.add('rich-calendar-btn');
}
- // TODO make some optimization with rich-calendar-current class
+ // TODO make some optimization with rich-calendar-today class
if (todayflag && dataobj._month==0 && dataobj.day==todaydate)
{
18 years, 8 months
JBoss Rich Faces SVN: r2510 - in trunk/docs/userguide/en/src/main: resources/images and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: vkukharchuk
Date: 2007-08-27 11:15:07 -0400 (Mon, 27 Aug 2007)
New Revision: 2510
Added:
trunk/docs/userguide/en/src/main/resources/images/scrollable-dt1.png
Modified:
trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.desc.xml
trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.xml
Log:
http://jira.jboss.com/jira/browse/RF-447
Modified: trunk/docs/userguide/en/src/main/docbook/included/scrollableDataTable.desc.xml
===================================================================